Compile-time bridge from Rust kernel functions to Ruda IR.
Macros
- comment
- Insert a literal comment into the kernel source code.
- comptime
- Mark the contents of this macro as compile time values, turning off all expansion for this code and using it verbatim
- comptime_
type - Makes the function return a compile time value Useful in a ruda trait to have a part of the trait return comptime values
- intrinsic
- Mark the contents of this macro as an intrinsic, turning off all expansion for this code and calling it with the scope
- terminate
- Terminate the execution of the kernel for the current unit.
Attribute Macros
- derive_
expand - Attribute macro to derive ruda traits for existing structs, without redefining that struct.
- derive_
ruda_ comptime - Attribute macro to define a type that can be used as a kernel comptime
argument This derive Debug, Hash,
PartialEq, Eq, Clone, Copy - ruda
- Mark a ruda function, trait or implementation for expansion.
Derive Macros
- Autotune
Key - Implements display and initialization for autotune keys.
- Into
Runtime - Implements
IntoRuntimefor aRudaType - Ruda
Launch - Derive macro to define a ruda type that is launched with a kernel
- Ruda
Type - Derive macro to define a ruda type that is not launched
- Ruda
Type Mut - Implements mutability for a
RudaType