#[derive(RudaLaunch)]
{
// Attributes available to this derive:
#[ruda]
#[launch]
}
Derive macro to define a ruda type that is launched with a kernel
#[derive(RudaLaunch)]
{
// Attributes available to this derive:
#[ruda]
#[launch]
}
Derive macro to define a ruda type that is launched with a kernel